@@ -1,11 +1,13 @@
 package App::Monport;
 use App::Cmd::Setup -app;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
+
+=for HTML <a href="https://travis-ci.org/jreisinger/App-Monport"><img src="https://travis-ci.org/jreisinger/App-Monport.svg?branch=master"></a>
 
 =head1 NAME
 
-App::Monport - monitor network ports for changes
+App::Monport - Monitor network ports for changes
 
 =head1 SYNOPSIS
 
@@ -21,15 +23,17 @@ consequently higher security risk.
 
 First you should run a base scan, like:
 
- $ monport base --name localhost 127.0.0.1
+ $ monport base --name "test scan" localhost 192.168.1.0/24
 
 Later on check whether some changes in ports' state took place:
 
- $ monport diff --name localhost
+ $ monport diff --name "test scan"
+ 192.168.1.10 () has changes in port(s) state
+  3333 (dec-notes) -- not-open => open
 
 To check regularly create a cronjob like:
 
- * 21 * * 5      monport --diff --name localhost --email jdoe@example.com
+ * 21 * * 5      monport diff --name "test scan" --email jdoe@example.com
 
 =head1 INSTALLATION
 
