@@ -1,6 +1,21 @@
 package App::Monport::Command;
 use App::Cmd::Setup -command;
 
+=head1 DESCRIPTION
+
+Global options, i.e. options available for all sub-commands, are defined here.
+See App::Cmd::Tutorial#Global-Options for more.
+
+=cut
+
+=head1 METHODS
+
+=head2 opt_spec()
+
+Global options.
+
+=cut
+
 sub opt_spec {
   my ( $class, $app ) = @_;
   return (
@@ -11,6 +26,12 @@ sub opt_spec {
   )
 }
 
+=head2 validate_args()
+
+Validate global arguments.
+
+=cut
+
 sub validate_args {
   my ( $self, $opt, $args ) = @_;
   if ( $opt->{help} ) {
